/* @file HelloKeypad.pde
  || @version 1.0
  || @author Alexander Brevig
  || @contact alexanderbrevig@gmail.com
  ||
  || @description
  || | Demonstrates the simplest use of the matrix Keypad library.
  || #
*/
#include <Keypad.h>
#include <NewPing.h>
#include <Servo.h>
#include <Password.h>

#define TRIGGER_PIN  12  // Arduino pin tied to trigger pin on the ultrasonic sensor.
#define ECHO_PIN     11  // Arduino pin tied to echo pin on the ultrasonic sensor.
#define MAX_DISTANCE 400 // Maximum distance we want to ping for (in centimeters). Maximum sensor distance is rated at 400-500cm.

NewPing sonar(TRIGGER_PIN, ECHO_PIN, MAX_DISTANCE); // NewPing setup of pins and maximum distance.

Servo myMotor;
int servoPin = 10;
int distance;

const byte ROWS = 4; //four rows
const byte COLS = 4; //three columns
char keys[ROWS][COLS] = {
  {'1', '2', '3', 'A'},
  {'4', '5', '6', 'B'},
  {'7', '8', '9', 'C'},
  {'*', '0', '#', 'D'}
};
byte rowPins[ROWS] = {2, 3, 4, 5}; //connect to the row pinouts of the keypad
byte colPins[COLS] = {6, 7, 8, 9}; //connect to the column pinouts of the keypad

Keypad keypad = Keypad( makeKeymap(keys), rowPins, colPins, ROWS, COLS );
Password password = Password("CAB1");
byte currentPasswordLength = 0;
byte maxPasswordLength = 6;
bool sonarMode = false;

void setup() {
  Serial.begin(9600);
  myMotor.attach(servoPin);
  myMotor.write(170);
}


  void switchMode(){
  sonarMode = !sonarMode;
  }

void loop() {
  char key = keypad.getKey();
  
    if (key != NO_KEY) {
      switch (key) {
        case 'D': break;
        case '*': switchMode(); break;
        case '#': checkPassword(); break;
        default: processNumberKey(key);
      }
    }
  if (sonarMode) {
    distance = sonar.ping_cm();
    if (millis() % 1000 == 0){
      Serial.println(distance);
      if (distance > 5 && distance < 60) {
        Serial.println("Open");
        myMotor.write(10);
      }else{
        Serial.println("Close");
        myMotor.write(170);
      }

    }
  }
}

  void processNumberKey(char key) {
    Serial.print(key);
    currentPasswordLength++;
    password.append(key);
    if (currentPasswordLength == maxPasswordLength) {
      checkPassword();
    }
  }

  void checkPassword() {
    if (password.evaluate()) {
      Serial.println(" OK.");
      myMotor.write(10);
      
    } else {
      Serial.println(" Wrong passwowrd!");
      myMotor.write(170);
    }
    resetPassword();
  }

  void resetPassword() {
    password.reset();
    currentPasswordLength = 0;
  }
